Documentation
¶
Overview ¶
Package minequery is a simple library to query Minequery enabled Minecraft servers.
Index ¶
Constants ¶
const ( // DefaultPort is the default Minequery network port. // More information: https://github.com/vexsoftware/minequery/blob/v1.5/java/net/minestatus/minequery/Minequery.java#L65 DefaultPort = 25566 )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Response ¶
type Response struct {
ServerPort int `json:"serverPort"`
PlayerCount int `json:"playerCount"`
MaxPlayers int `json:"maxPlayers"`
PlayerList []string `json:"playerList"`
}
Response is a representation of the Minequery server QUERY_JSON response. More information: https://github.com/vexsoftware/minequery/blob/v1.5/java/net/minestatus/minequery/Request.java#L108
func Query ¶
Query connects and requests a response from the Minequery server at the specified address. Follows Minequery server's Java implementation: https://github.com/vexsoftware/minequery/blob/v1.5/java/net/minestatus/minequery/Request.java#L21
Click to show internal directories.
Click to hide internal directories.